@@ -14,15 +14,15 @@ sub new {
 
 sub run {
     my $self = shift;
-    my $pool = SVN::Pool->new_default_sub;
     my $fs = $self->{repos}->fs;
     my $rev = $self->{cgi}->param('rev') || $fs->youngest_rev;
     if ($self->{path} !~ m|/$|) {
 	return 'internal server error';
     }
+    my $path = $self->{path};
+    $path =~ s|/$|| unless $path eq '/';
     my $root = $fs->revision_root ($rev);
-    my $kind = $root->check_path ($self->{path});
-
+    my $kind = $root->check_path ($path);
     die "path does not exist" if $kind == $SVN::Node::none;
 
     die "not a directory in browse" unless $kind == $SVN::Node::dir;
@@ -33,6 +33,7 @@ sub run {
 		       }} values %{$root->dir_entries ($self->{path})}];
 
 
+    my $spool = SVN::Pool->new_default;
     for (@$entries) {
 	my $path = "$self->{path}$_->{name}";
 	$_->{rev} = ($fs->revision_root ($rev)->node_history
@@ -42,7 +43,7 @@ sub run {
 	$_->{type} = $root->node_prop ($self->{path}.$_->{name},
 				       'svn:mime-type') unless $_->{isdir};
 	$_->{type} =~ s|/\w+|| if $_->{type};
-
+	$spool->clear;
     }
 
     # TODO: custom sorting
