@@ -19,13 +19,12 @@ sub run {
     my $rev = $self->{cgi}->param('rev') || $fs->youngest_rev;
     my $root = $fs->revision_root ($rev);
 
-    die "not a file" unless SVN::Fs::check_path ($root, $self->{path})
-	== $SVN::Core::node_file;
+    die "not a file" unless $root->is_file ($self->{path});
 
-    my $file = SVN::Fs::file_contents ($root, $self->{path});
+    my $file = $root->file_contents ($self->{path});
     local $/;
-    return {mimetype => SVN::Fs::node_prop ($root, $self->{path},
-					    'svn:mime-type') ||'text/plain',
+    return {mimetype => $root->node_prop ($self->{path},
+					  'svn:mime-type') ||'text/plain',
 	    body => <$file>};
 }
 1;
