@@ -9,7 +9,7 @@ sub run {
     my $data = $self->SUPER::run(@_)->{data};
 
     my $rss = new XML::RSS (version => '1.0');
-    my $url = "http://$ENV{HTTP_HOST}$ENV{SCRIPT_NAME}/$self->{reposname}";
+    my $url = "http://$ENV{HTTP_HOST}$self->{script}/$self->{reposname}";
 
     $rss->channel(title        => "subversion revisions of $self->{path}",
 		  link         => "$url/log$self->{path}",
@@ -26,7 +26,8 @@ sub run {
 		 );
 
     $_ && $rss->add_item
-	( title       => "revision $_->{rev}",
+	( title       => "$_->{rev} - ".substr ((split("\n",$_->{msg}, 1))[0],
+						0, 40),
 	  link        => "$url/revision/?rev=$_->{rev}",
 	  dc => { date		=> $_->{date},
 		  creator	=> $_->{author},
